==> jugg-agile-middleware-mongodb-2.0-agile-mongodb-20250828.024641-28-sources.jar: com/jugg/agile/middleware/mongodb/dapper/JaNodeSpanMongoTemplate.java <==
package com.jugg.agile.middleware.mongodb.dapper;

import com.jugg.agile.framework.core.config.JaProperty;
import com.jugg.agile.framework.core.dapper.aspect.JaDapperAspectPointcut;
import com.jugg.agile.framework.core.dapper.aspect.JaNodeSpanResolver;
import com.jugg.agile.framework.core.dapper.meta.NodeKind;
import com.jugg.agile.framework.core.dapper.meta.NodeSpan;
import com.jugg.agile.framework.core.util.bytecode.aop.JaAopUtil;
import com.jugg.agile.framework.core.util.datastructure.JaCollectionUtil;
import org.aopalliance.intercept.MethodInvocation;
import org.springframework.aop.framework.ReflectiveMethodInvocation;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.stereotype.Component;

import java.util.ArrayList;

@Component
@ConditionalOnClass(name = {JaNodeSpanMongoTemplate.ProxyClassName})
public class JaNodeSpanMongoTemplate implements JaNodeSpanResolver, JaDapperAspectPointcut {

    public static final String ProxyClassName = "org.springframework.data.mongodb.core.MongoTemplate";

    private static final NodeKind mongoTemplateNodeKind = new NodeKind("mongodb")
            .buildIdHandler(JaAopUtil::getSimpleName)
            // dap框架版本, 应对gson bug
            .buildReqArgsHandler(JaProperty.getInteger("ja.log.json.type", 0) == 2 ? args -> {
                if (JaCollectionUtil.isEmpty(args)) {
                    return args;
                }
                ArrayList<Object> objects = new ArrayList<>(args.length);
                for (Object arg : args) {
                    if (arg instanceof Query
                            || arg instanceof Class
                    ) {
                        continue;
                    }
                    objects.add(arg);
                }
                return objects.toArray();
            } : null);

    @Override
    public NodeSpan getNodeSpan(MethodInvocation invocation) {
        if (invocation instanceof ReflectiveMethodInvocation) {
            Object proxy = ((ReflectiveMethodInvocation) invocation).getProxy();
            if (proxy.toString().startsWith(ProxyClassName)) {
                return get(mongoTemplateNodeKind);
            }
        }
        return null;
    }

    @Override
    public String getExpression() {
        return "execution(* org.springframework.data.mongodb.core.MongoOperations.*(..))";
    }

}

==> jugg-agile-middleware-mongodb-2.6.13.0-agile-mongodb-20250902.015409-5-sources.jar: com/jugg/agile/middleware/mongodb/dapper/JaNodeSpanMongoTemplate.java <==
package com.jugg.agile.middleware.mongodb.dapper;

import com.jugg.agile.framework.core.dapper.aspect.JaDapperAspectPointcut;
import com.jugg.agile.framework.core.dapper.aspect.JaNodeSpanResolver;
import com.jugg.agile.framework.core.dapper.meta.NodeKind;
import com.jugg.agile.framework.core.dapper.meta.NodeSpan;
import com.jugg.agile.framework.core.util.bytecode.aop.JaAopUtil;
import org.aopalliance.intercept.MethodInvocation;
import org.springframework.aop.framework.ReflectiveMethodInvocation;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.stereotype.Component;

@Component
@ConditionalOnClass(name = {JaNodeSpanMongoTemplate.ProxyClassName})
public class JaNodeSpanMongoTemplate implements JaNodeSpanResolver, JaDapperAspectPointcut {

    public static final String ProxyClassName = "org.springframework.data.mongodb.core.MongoTemplate";

    private static final NodeKind mongoTemplateNodeKind = new NodeKind("mongodb")
            .buildIdHandler(JaAopUtil::getSimpleName);

    @Override
    public NodeSpan getNodeSpan(MethodInvocation invocation) {
        if (invocation instanceof ReflectiveMethodInvocation) {
            Object proxy = ((ReflectiveMethodInvocation) invocation).getProxy();
            if (proxy.toString().startsWith(ProxyClassName)) {
                return get(mongoTemplateNodeKind);
            }
        }
        return null;
    }

    @Override
    public String getExpression() {
        return "execution(* org.springframework.data.mongodb.core.MongoOperations.*(..))";
    }

}
